=======
Authors
=======

Development Team
----------------

* Exneyder A. Montoya-Araque, Geol.Eng., MEng., <eamontoyaa@unal.edu.co>
* Alan J. Aparicio-Ortube, Civ.Eng., MSc., PhD. Student,  <aaparicioo@unal.edu.co>

Contributors/Advisors
---------------------

* David G. Zapata-Medina, Civ.Eng., MSc., PhD. <dgzapata@unal.edu.co>
* Luis G. Arboleda-Monsalve, Civ.Eng., MSc., PhD. <luis.Arboleda@ucf.edu>
